==> org-lsst-ccs-subsystem-rafts-buses-1.10.6-sources.jar: org/lsst/ccs/subsystem/rafts/fpga/xml/FunctionPointer.java <==
package org.lsst.ccs.subsystem.rafts.fpga.xml;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlIDREF;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;

import org.lsst.ccs.subsystem.rafts.fpga.compiler.Visitor;

@XmlType
public class FunctionPointer implements Visitable{

    public FunctionPointer() {

    }

    public FunctionPointer(String id, String fullname, Function fcn) {
        super();
        this.id = id;
        this.fullname = fullname;
        this.fcn = fcn;
    }
    
    public FunctionPointer(String id, String fullname, String fcnName) {
        super();
        this.id = id;
        this.fullname = fullname;
        this.fcnName = fcnName;
    }


    @XmlAttribute(name = "id")
    @XmlID
    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    @XmlElement(name = "fullname")
    public String getFullname() {
        return fullname;
    }

    public void setFullname(String fullname) {
        this.fullname = fullname;
    }

    // initial value
    @XmlIDREF
    @XmlAttribute(name = "fcn")
    public Function getFunction() {
        return fcn;
    }

    public void setFunction(Function fcn) {
        this.fcn = fcn;
    }
    
    
    @Override
    public void accept(Visitor v) {
        v.visit(this);
    }
    
    @XmlTransient
    public String getFcnName() {
        return fcnName;
    }
    
    public void setFcnName(String fcnName) {
        this.fcnName = fcnName;
    }


    private String id;
    private Function fcn;
    private String fcnName;
    String fullname;
}

==> org-lsst-ccs-subsystem-rafts-buses-2.0.3-sources.jar: org/lsst/ccs/subsystem/rafts/fpga/xml/FunctionPointer.java <==
package org.lsst.ccs.subsystem.rafts.fpga.xml;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlIDREF;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;

import org.lsst.ccs.subsystem.rafts.fpga.compiler.Visitor;

@XmlType
public class FunctionPointer implements Visitable, Serializable {

    private static final long serialVersionUID = 4029230344322186608L;

    public FunctionPointer() {

    }

    public FunctionPointer(String id, String fullname, Function fcn) {
        super();
        this.id = id;
        this.fullname = fullname;
        this.fcn = fcn;
    }
    
    public FunctionPointer(String id, String fullname, String fcnName) {
        super();
        this.id = id;
        this.fullname = fullname;
        this.fcnName = fcnName;
    }


    @XmlAttribute(name = "id")
    @XmlID
    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    @XmlElement(name = "fullname")
    public String getFullname() {
        return fullname;
    }

    public void setFullname(String fullname) {
        this.fullname = fullname;
    }

    // initial value
    @XmlIDREF
    @XmlAttribute(name = "fcn")
    public Function getFunction() {
        return fcn;
    }

    public void setFunction(Function fcn) {
        this.fcn = fcn;
    }
    
    
    @Override
    public void accept(Visitor v) {
        v.visit(this);
    }
    
    @XmlTransient
    public String getFcnName() {
        return fcnName;
    }
    
    public void setFcnName(String fcnName) {
        this.fcnName = fcnName;
    }


    private String id;
    private Function fcn;
    private String fcnName;
    String fullname;
}
